"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Plumier = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@plumier/core");
const koa_1 = tslib_1.__importDefault(require("koa"));
const path_1 = require("path");
class Plumier {
    constructor() {
        this.koa = new koa_1.default();
        this.config = {
            mode: "debug",
            controller: [
                require.main.filename,
                "./**/*controller.+(ts|js)",
                "./**/*entity.+(ts|js)"
            ],
            dependencyResolver: new core_1.DefaultDependencyResolver(),
            middlewares: [],
            facilities: [],
            enableAuthorization: false,
            rootDir: "__UNSET__",
            trustProxyHeader: false,
            typeConverterVisitors: [],
            authPolicies: [],
            globalAuthorizations: []
        };
    }
    use(middleware, scope = "Global") {
        this.config.middlewares.push({ middleware, scope });
        return this;
    }
    set(config) {
        if ((0, core_1.hasKeyOf)(config, "setup")) {
            config.setup(this);
            this.config.facilities.push(config);
        }
        else
            Object.assign(this.config, config);
        return this;
    }
    async initialize() {
        try {
            if (process.env["NODE_ENV"] === "production")
                Object.assign(this.config, { mode: "production" });
            //get file location of script who initialized the application to calculate the controller path
            //module.parent.parent.filename -> because Plumier app also exported in plumier/src/index.ts
            if (this.config.rootDir === "__UNSET__")
                this.config.rootDir = (0, path_1.dirname)(require.main.filename);
            //pre initialize
            for (const facility of this.config.facilities) {
                await facility.preInitialize(this);
            }
            //generate routes 
            const routes = [];
            for (const facility of this.config.facilities) {
                const genRoutes = await facility.generateRoutes(this, routes);
                routes.push(...genRoutes);
            }
            //run initialize
            for (const facility of this.config.facilities) {
                await facility.initialize(this, routes);
            }
            if (this.config.mode === "debug") {
                (0, core_1.printAnalysis)((0, core_1.analyzeRoutes)(routes, this.config));
            }
            const actionRoutes = routes.filter((x) => x.kind === "ActionRoute");
            this.koa.use((0, core_1.router)(actionRoutes, this.config));
            this.koa.proxy = this.config.trustProxyHeader;
            return this.koa;
        }
        catch (e) {
            throw e;
        }
    }
    async listen(port) {
        const app = await this.initialize();
        let envPort;
        if (typeof port === "string") {
            const result = parseInt(port);
            if (isNaN(result))
                throw Error(`Unable to parse port number ${port}. Please provide a valid integer number`);
            envPort = result;
        }
        else
            envPort = port;
        if (this.config.mode === "debug")
            console.log(`Server ready http://localhost:${envPort}/`);
        return app.listen(envPort);
    }
}
exports.Plumier = Plumier;
